summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorMonsta <[email protected]>2015-08-08 18:21:20 +0300
committerMonsta <[email protected]>2015-08-08 18:21:20 +0300
commitd5304e0637b31a961a5ceb8a6a5b448577d5990f (patch)
tree5b3e1457a227f8c38c9de81ae8ed4d7773225c95
parentd800546a3c93d44285be5d519201edc8b9427b7f (diff)
downloadmate-power-manager-d5304e0637b31a961a5ceb8a6a5b448577d5990f.tar.bz2
mate-power-manager-d5304e0637b31a961a5ceb8a6a5b448577d5990f.tar.xz
inhibit applet: use GtkWidget instead of GtkObject
-rw-r--r--applets/inhibit/inhibit-applet.c12
1 files changed, 4 insertions, 8 deletions
diff --git a/applets/inhibit/inhibit-applet.c b/applets/inhibit/inhibit-applet.c
index eae73fd..58f2c88 100644
--- a/applets/inhibit/inhibit-applet.c
+++ b/applets/inhibit/inhibit-applet.c
@@ -49,10 +49,6 @@
#define GPM_IS_INHIBIT_APPLET_CLASS(k) (G_TYPE_CHECK_CLASS_TYPE ((k), GPM_TYPE_INHIBIT_APPLET))
#define GPM_INHIBIT_APPLET_GET_CLASS(o) (G_TYPE_INSTANCE_GET_CLASS ((o), GPM_TYPE_INHIBIT_APPLET, GpmInhibitAppletClass))
-#if GTK_CHECK_VERSION (3, 0, 0)
-#define GtkObject GtkWidget
-#endif
-
typedef struct{
MatePanelApplet parent;
/* applet state */
@@ -91,7 +87,7 @@ static void gpm_applet_update_tooltip (GpmInhibitApplet *applet);
static gboolean gpm_applet_click_cb (GpmInhibitApplet *applet, GdkEventButton *event);
static void gpm_applet_dialog_about_cb (GtkAction *action, gpointer data);
static gboolean gpm_applet_cb (MatePanelApplet *_applet, const gchar *iid, gpointer data);
-static void gpm_applet_destroy_cb (GtkObject *object);
+static void gpm_applet_destroy_cb (GtkWidget *widget);
#define GPM_INHIBIT_APPLET_ID "InhibitApplet"
#define GPM_INHIBIT_APPLET_FACTORY_ID "InhibitAppletFactory"
@@ -533,12 +529,12 @@ gpm_applet_help_cb (GtkAction *action, gpointer data)
/**
* gpm_applet_destroy_cb:
* @object: Class instance to destroy
**/
static void
-gpm_applet_destroy_cb (GtkObject *object)
+gpm_applet_destroy_cb (GtkWidget *widget)
{
- GpmInhibitApplet *applet = GPM_INHIBIT_APPLET(object);
+ GpmInhibitApplet *applet = GPM_INHIBIT_APPLET(widget);
if (applet->monitor != NULL) {
g_object_unref (applet->monitor);
@@ -533,12 +529,12 @@ gpm_applet_help_cb (GtkAction *action, gpointer data)
/**
* gpm_applet_destroy_cb:
- * @object: Class instance to destroy
+ * @widget: Class instance to destroy
**/
static void